@@ -5,10 +5,12 @@ pycraigslist.models.sessions
 Handles requests and constructs BeautifulSoup objects.
 """
 
+import cchardet
 import concurrent.futures
+import lxml
 import tenacity
 import requests
-from bs4 import BeautifulSoup
+from bs4 import BeautifulSoup, SoupStrainer
 from pycraigslist.exceptions import MaximumRequestsError
 
 HEADERS = {"headers": {"User-Agent": "Mozilla/5.0"}}
@@ -21,33 +23,64 @@ _RETRY_ARGS = {
 
 def yield_html(url, **kwargs):
     """Yields HTML content(s) to caller."""
+    session = requests.Session()
+    strainer = get_cl_strainer()
     try:
         # Single request: a url string
         if isinstance(url, str):
-            yield get_html(get_request(url, **parse_kwargs(kwargs)).content)
+            yield get_html(get_request(session, url, **parse_kwargs(kwargs)).text, strainer)
         # Single request: a single url in a list or tuple
         elif isinstance(url, (list, tuple)) and len(url) == 1:
-            yield get_html(get_request(url[0], **parse_kwargs(kwargs)).content)
+            yield get_html(get_request(session, url[0], **parse_kwargs(kwargs)).text, strainer)
         # Multiple requests
         else:
+            # Build iterables of session and strainer objects equal in length to url tuple
+            sessions = make_iterable(session, len(url))
+            strainers = make_iterable(strainer, len(url))
             yield from map(
                 get_html,
                 (
-                    response.content
-                    for response in threaded_get_request(url, **parse_kwargs(kwargs))
+                    response.text
+                    for response in threaded_get_request(sessions, url, **parse_kwargs(kwargs))
                 ),
+                strainers,
             )
     except tenacity.RetryError:
         raise MaximumRequestsError("Maximum requests attempted - check network connection.")
 
 
-def get_html(content):
-    """Gets bs4.BeautifulSoup object from response content."""
-    return BeautifulSoup(content, "html.parser")
+def get_cl_strainer():
+    """Gets bs4.SoupStrainer object, targeting relevant sections of the Craigslist page."""
+
+    def target_elem_attrs(elem, attrs):
+        """Gets desired elements and attributes from Craigslist HTML document."""
+        # For pycraigslist.models.search_detail
+        if elem == "section" and attrs.get("class") == "userbody":
+            return True
+        # For pycraigslist.models.search
+        elif elem == "script" and attrs.get("type") == "text/javascript":
+            return True
+        # Whitespace after 'search-attribute' (index 0) is necessary
+        elif elem == "div" and attrs.get("class") in [
+            "search-attribute ",
+            "search-attribute hide-list",
+        ]:
+            return True
+        elif elem == "span" and attrs.get("class") == "totalcount":
+            return True
+        elif elem == "ul" and attrs.get("class") == "rows":
+            return True
+
+    return SoupStrainer(target_elem_attrs)
+
+
+def get_html(text, strainer):
+    """Gets bs4.BeautifulSoup object from response text."""
+    return BeautifulSoup(text, "lxml", parse_only=strainer)
 
 
 @tenacity.retry(**_RETRY_ARGS)
-def get_request(url, params=None):
+def get_request(requests_session, url, params=None):
     """Gets requests.models.Response object using requests.get.
     Retry request if request fails, with number of attempts and
     wait time specified in _RETRY_ARGS."""
@@ -56,15 +89,18 @@ def get_request(url, params=None):
     # Don't add headers if params is {}
     elif params != {}:
         params.update(HEADERS)
-
-    return requests.get(url, params=params, timeout=5)
+    return requests_session.get(url, params=params, timeout=5)
 
 
-def threaded_get_request(urls, **kwargs):
+def threaded_get_request(sessions, urls, **kwargs):
     """Yields requests from get_request concurrently."""
     yield from iter(
         concurrency(
-            concurrent.futures.ThreadPoolExecutor, lambda args: get_request(*args), urls, **kwargs
+            concurrent.futures.ThreadPoolExecutor,
+            lambda args: get_request(*args),
+            sessions,
+            urls,
+            **kwargs
         )
     )
 
@@ -91,3 +127,8 @@ def parse_kwargs(kwargs):
         if isinstance(value, (list, tuple)) and len(value) == 1:
             kwargs[key] = value[0]
     return kwargs
+
+
+def make_iterable(target, count):
+    """Returns iterable of target object equal in length to count."""
+    return (target for _ in range(count))
